@@ -83,7 +83,7 @@ sub apply_logic {
     # NOTE2: still, solving 10000 from hard_sudokus.txt ($MAX_SOLUTIONS = 0; full traversal) became 20% faster by doing locked_candidates first
 
     unless ($last_filled) {
-      last; # skip further efforts to reduce the candidates (advanced methods)
+      #### last; # skip further efforts to reduce the candidates (advanced methods)
 
       my $last_dropped = 0;
 
